@@ -2,9 +2,9 @@
 /**
  * Horde_Data implementation for tab-separated data (TSV).
  *
- * $Horde: framework/Data/Data/tsv.php,v 1.23.10.10 2006/08/03 02:50:40 selsky Exp $
+ * $Horde: framework/Data/Data/tsv.php,v 1.23.10.12 2007/01/02 13:54:12 jan Exp $
  *
- * Copyright 1999-2006 Jan Schneider <jan@horde.org>
+ * Copyright 1999-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -21,6 +21,9 @@ class Horde_Data_tsv extends Horde_Data {
 
     function importData($contents, $header = false, $delimiter = "\t")
     {
+        if ($_SESSION['import_data']['format'] == 'pine') {
+            $contents = preg_replace('/\n +/', '', $contents);
+        }
         $contents = explode("\n", $contents);
         $data = array();
         if ($header) {
