@@ -31,7 +31,7 @@ define('HORDE_DATE_MASK_ALLPARTS', 63);
  * Horde Date wrapper/logic class, including some calculation
  * functions.
  *
- * $Horde: framework/Date/Date.php,v 1.8.10.7 2006/05/04 03:42:32 selsky Exp $
+ * $Horde: framework/Date/Date.php,v 1.8.10.8 2006/11/24 23:52:56 chuck Exp $
  *
  * @package Horde_Date
  */
@@ -92,8 +92,8 @@ class Horde_Date {
                 }
             }
         } elseif (!is_null($date)) {
-            // Match YYYY-MM-DD HH:MM:SS and YYYYMMDDHHMMSS.
-            if (preg_match('/(\d{4})-?(\d{2})-?(\d{2}) ?(\d{2}):?(\d{2}):?(\d{2})/', $date, $parts)) {
+            // Match YYYY-MM-DD HH:MM:SS, YYYYMMDDHHMMSS and YYYYMMDD'T'HHMMSS'Z'.
+            if (preg_match('/(\d{4})-?(\d{2})-?(\d{2})T? ?(\d{2}):?(\d{2}):?(\d{2})Z?/', $date, $parts)) {
                 $this->year = (int)$parts[1];
                 $this->month = (int)$parts[2];
                 $this->mday = (int)$parts[3];
@@ -151,6 +151,8 @@ class Horde_Date {
      * Returns the day of the year (1-366) that corresponds to the
      * first day of the given week.
      *
+     * TODO: with PHP 5.1+, see http://derickrethans.nl/calculating_start_and_end_dates_of_a_week.php
+     *
      * @param integer $week  The week of the year to find the first day of.
      * @param integer $year  The year to calculate for.
      *
@@ -158,7 +160,7 @@ class Horde_Date {
      */
     function firstDayOfWeek($week, $year)
     {
-        $jan1 = &new Horde_Date(array('year' => $year, 'month' => 1, 'mday' => 1));
+        $jan1 = new Horde_Date(array('year' => $year, 'month' => 1, 'mday' => 1));
         $start = $jan1->dayOfWeek();
         if ($start > HORDE_DATE_THURSDAY) {
             $start -= 7;
@@ -219,7 +221,7 @@ class Horde_Date {
         $monthTotals = array(0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334);
         $dayOfYear = $this->mday + $monthTotals[$this->month - 1];
         if (Horde_Date::isLeapYear($this->year) && $this->month > 2) {
-            $dayOfYear++;
+            ++$dayOfYear;
         }
 
         return $dayOfYear;
@@ -248,10 +250,10 @@ class Horde_Date {
         // Find the last Thursday of the year.
         $day = 31;
         while (date('w', mktime(0, 0, 0, 12, $day, $year)) != HORDE_DATE_THURSDAY) {
-            $day--;
+            --$day;
         }
 
-        $date = &new Horde_Date(array('year' => $year, 'month' => 12, 'mday' => $day));
+        $date = new Horde_Date(array('year' => $year, 'month' => 12, 'mday' => $day));
         return $date->weekOfYear();
     }
 
@@ -308,44 +310,44 @@ class Horde_Date {
     {
         if ($mask & HORDE_DATE_MASK_SECOND) {
             while ($this->sec < 0) {
-                $this->min--;
+                --$this->min;
                 $this->sec += 60;
             }
             while ($this->sec > 59) {
-                $this->min++;
+                ++$this->min;
                 $this->sec -= 60;
             }
         }
 
         if ($mask & HORDE_DATE_MASK_MINUTE) {
             while ($this->min < 0) {
-                $this->hour--;
+                --$this->hour;
                 $this->min += 60;
             }
             while ($this->min > 59) {
-                $this->hour++;
+                ++$this->hour;
                 $this->min -= 60;
             }
         }
 
         if ($mask & HORDE_DATE_MASK_HOUR) {
             while ($this->hour < 0) {
-                $this->mday--;
+                --$this->mday;
                 $this->hour += 24;
             }
             while ($this->hour > 23) {
-                $this->mday++;
+                ++$this->mday;
                 $this->hour -= 24;
             }
         }
 
         if ($mask & HORDE_DATE_MASK_MONTH) {
             while ($this->month > 12) {
-                $this->year++;
+                ++$this->year;
                 $this->month -= 12;
             }
             while ($this->month < 1) {
-                $this->year--;
+                --$this->year;
                 $this->month += 12;
             }
         }
@@ -353,11 +355,11 @@ class Horde_Date {
         if ($mask & HORDE_DATE_MASK_DAY) {
             while ($this->mday > Horde_Date::daysInMonth($this->month, $this->year)) {
                 $this->mday -= Horde_Date::daysInMonth($this->month, $this->year);
-                $this->month++;
+                ++$this->month;
                 $this->correct(HORDE_DATE_MASK_MONTH);
             }
             while ($this->mday < 1) {
-                $this->month--;
+                --$this->month;
                 $this->correct(HORDE_DATE_MASK_MONTH);
                 $this->mday += Horde_Date::daysInMonth($this->month, $this->year);
             }
@@ -378,7 +380,7 @@ class Horde_Date {
     function compareDate($date)
     {
         if (!is_a($date, 'Horde_Date')) {
-            $date = &new Horde_Date($date);
+            $date = new Horde_Date($date);
         }
 
         if ($this->year != $date->year) {
@@ -404,7 +406,7 @@ class Horde_Date {
     function compareTime($date)
     {
         if (!is_a($date, 'Horde_Date')) {
-            $date = &new Horde_Date($date);
+            $date = new Horde_Date($date);
         }
 
         if ($this->hour != $date->hour) {
@@ -430,7 +432,7 @@ class Horde_Date {
     function compareDateTime($date)
     {
         if (!is_a($date, 'Horde_Date')) {
-            $date = &new Horde_Date($date);
+            $date = new Horde_Date($date);
         }
 
         if ($diff = $this->compareDate($date)) {
