@@ -2,15 +2,14 @@
 /**
  * IMAP_Sort provides functions for sorting lists of IMAP mailboxes/folders.
  *
- * $Horde: framework/IMAP/IMAP/Sort.php,v 1.6.8.3 2005/02/10 07:01:39 slusarz Exp $
+ * $Horde: framework/IMAP/IMAP/Sort.php,v 1.6.8.14 2007/01/02 13:54:22 jan Exp $
  *
- * Copyright 2004-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2004-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.6.8.3 $
  * @since   Horde 3.0
  * @package Horde_IMAP
  */
@@ -19,22 +18,20 @@ class IMAP_Sort {
     /**
      * The delimiter character to use.
      *
-     * @var string $_delimiter
+     * @var string
      */
-    var $_delimiter = '/';
+    var $_delimiter;
 
     /**
      * Should we sort with 'INBOX' at the front of the list?
      *
-     * @var boolean $_sortinbox
+     * @var boolean
      */
     var $_sortinbox;
 
     /**
      * Constructor.
      *
-     * @access public
-     *
      * @param string $delimiter  The delimiter used to separate mailboxes.
      */
     function IMAP_Sort($delimiter)
@@ -45,27 +42,28 @@ class IMAP_Sort {
     /**
      * Sort a list of mailboxes (by value).
      *
-     * @access public
-     *
-     * @param array &$mbox             The list of mailboxes to sort.
-     * @param optional boolean $inbox  When sorting, always put 'INBOX' at
-     *                                 the head of the list?
+     * @param array &$mbox    The list of mailboxes to sort.
+     * @param boolean $inbox  When sorting, always put 'INBOX' at the head of
+     *                        the list?
+     * @param boolean $index  Maintain index association?
      */
-    function sortMailboxes(&$mbox, $inbox = true)
+    function sortMailboxes(&$mbox, $inbox = true, $index = false)
     {
         $this->_sortinbox = $inbox;
-        usort($mbox, array(&$this, '_mbox_cmp'));
+        if ($index) {
+            uasort($mbox, array(&$this, '_mbox_cmp'));
+        } else {
+            usort($mbox, array(&$this, '_mbox_cmp'));
+        }
     }
 
     /**
      * Sort a list of mailboxes (by key).
      *
-     * @access public
-     *
-     * @param array &$mbox             The list of mailboxes to sort, with
-     *                                 the keys being the mailbox names.
-     * @param optional boolean $inbox  When sorting, always put 'INBOX' at
-     *                                 the head of the list?
+     * @param array &$mbox    The list of mailboxes to sort, with the keys
+     *                        being the mailbox names.
+     * @param boolean $inbox  When sorting, always put 'INBOX' at the head of
+     *                        the list?
      */
     function sortMailboxesByKey(&$mbox, $inbox = true)
     {
@@ -115,7 +113,11 @@ class IMAP_Sort {
                         return 1;
                     }
                 }
-                return strnatcasecmp($a_parts[$i], $b_parts[$i]);
+                $cmp = strnatcasecmp($a_parts[$i], $b_parts[$i]);
+                if ($cmp == 0) {
+                    return strcmp($a_parts[$i], $b_parts[$i]);
+                }
+                return $cmp;
             }
         }
 
