@@ -4,16 +4,16 @@
  * methods take care of any site-specific restrictions configured in prefs.php
  * and conf.php.
  *
- * $Horde: framework/Prefs/Identity.php,v 1.1.2.2 2006/06/28 20:52:53 jan Exp $
+ * $Horde: framework/Prefs/Identity.php,v 1.1.2.6 2007/01/02 13:54:35 jan Exp $
  *
- * Copyright 2001-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
  * @since   Horde 1.3.5
- * @package Horde_Identity
+ * @package Horde_Prefs
  */
 class Identity {
 
@@ -76,7 +76,7 @@ class Identity {
 
         if (!($this->_identities = @unserialize($this->_prefs->getValue('identities', false)))) {
             /* Convert identities from the old format. */
-            $this->_identities = unserialize($this->_prefs->getValue('identities'));
+            $this->_identities = @unserialize($this->_prefs->getValue('identities'));
         } elseif (is_array($this->_identities)) {
             $this->_identities = $this->_prefs->convertFromDriver($this->_identities, NLS::getCharset());
         }
@@ -333,7 +333,7 @@ class Identity {
 
         $addr = $this->getValue('from_addr');
         if (empty($addr)) {
-            $addr = Auth::getAuth();
+            $addr = $this->_user;
         }
 
         return $from_addr . '<' . $addr . '>';
