@@ -47,9 +47,9 @@ require_once 'Horde/String.php';
  * </pre>
  *
  *
- * $Horde: framework/Prefs/Prefs/ldap.php,v 1.85.10.20 2006/06/21 20:07:55 jan Exp $
+ * $Horde: framework/Prefs/Prefs/ldap.php,v 1.85.10.22 2007/01/02 13:54:35 jan Exp $
  *
- * Copyright 1999-2006 Jon Parise <jon@horde.org>
+ * Copyright 1999-2007 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -155,7 +155,7 @@ class Prefs_ldap extends Prefs {
             Horde::logMessage(
                 sprintf('Failed to open an LDAP connection to %s.',
                         $this->_params['hostspec']),
-                __FILE__, __LINE__);
+                __FILE__, __LINE__, PEAR_LOG_ERR);
             return false;
         }
 
@@ -166,9 +166,9 @@ class Prefs_ldap extends Prefs {
                 Horde::logMessage(
                     sprintf('Set LDAP protocol version to %d failed: [%d] %s',
                             $this->_params['version'],
-                            ldap_errno($this->_connection),
-                            ldap_error($this->_connection)),
-                            __FILE__, __LINE__);
+                            ldap_errno($conn),
+                            ldap_error($conn)),
+                    __FILE__, __LINE__, PEAR_LOG_ERR);
             }
         }
 
@@ -178,12 +178,14 @@ class Prefs_ldap extends Prefs {
             $bind = @ldap_bind($conn, $this->_params['searchdn'],
                                $this->_params['searchpass']);
             if (!$bind) {
-                return PEAR::raiseError(sprintf('Bind to server %s:%d with DN %s failed: [%d] %s',
-                                                $this->_params['hostspec'],
-                                                $this->_params['port'],
-                                                $this->_params['searchdn'],
-                                                ldap_errno($this->_connection),
-                                                ldap_error($this->_connection)));
+                Horde::logMessage(sprintf('Bind to server %s:%d with DN %s failed: [%d] %s',
+                                          $this->_params['hostspec'],
+                                          $this->_params['port'],
+                                          $this->_params['searchdn'],
+                                          ldap_errno($conn),
+                                          ldap_error($conn)),
+                                  __FILE__, __LINE__, PEAR_LOG_ERR);
+                return false;
             }
 	}
 
@@ -192,9 +194,9 @@ class Prefs_ldap extends Prefs {
             !ldap_set_rebind_proc($conn, array($this, '_rebindProc'))) {
             Horde::logMessage(
                 sprintf('Set rebind proc failed: [%d] %s',
-                        ldap_errno($this->_connection),
-                        ldap_error($this->_connection)),
-                __FILE__, __LINE__);
+                        ldap_errno($conn),
+                        ldap_error($conn)),
+                __FILE__, __LINE__, PEAR_LOG_ERR);
             return false;
         }
 
@@ -228,7 +230,7 @@ class Prefs_ldap extends Prefs {
                             $bind_dn,
                             ldap_errno($this->_connection),
                             ldap_error($this->_connection)),
-                    __FILE__, __LINE__);
+                    __FILE__, __LINE__, PEAR_LOG_ERR);
                 return false;
             }
         }
@@ -255,7 +257,7 @@ class Prefs_ldap extends Prefs {
             sprintf('Failed to retrieve user\'s DN: [%d] %s',
                     ldap_errno($this->_connection),
                     ldap_error($this->_connection)),
-            __FILE__, __LINE__);
+            __FILE__, __LINE__, PEAR_LOG_ERR);
 
         return false;
     }
