@@ -11,9 +11,9 @@ require_once 'Horde.php';
  * entities -- If true the html entity versions of the patterns will be used.
  * </pre>
  *
- * $Horde: framework/Text_Filter/Filter/emoticons.php,v 1.17.10.10 2006/07/24 04:48:17 slusarz Exp $
+ * $Horde: framework/Text_Filter/Filter/emoticons.php,v 1.17.10.12 2007/01/02 13:54:43 jan Exp $
  *
- * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2007 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -37,38 +37,62 @@ class Text_Filter_emoticons extends Text_Filter {
      */
     function getPatterns()
     {
-        $regexp = array();
-        $iconpath = $GLOBALS['registry']->getImageDir('horde') . '/emoticons';
-
-        /* Loop through possible string emoticons and convert to graphics. */
-        foreach ($this->getIcons() as $string => $icon) {
-            $beg_pattern = '(^|\s)';
-            $end_pattern = '(?=\s)';
-            if ($this->_params['entities']) {
-                $string = htmlspecialchars($string);
-                $beg_pattern = '(^|\s|<br />|&nbsp;)';
-                $end_pattern = '(?=\s|<br />|&nbsp;)';
-            }
-
-            /* Check for a smiley either immediately at the start of a line or
-             * following a space. Use {} as the preg delimiters as this is not
-             * found in any smiley. */
-            $regexp['{' . $beg_pattern . preg_quote($string) . $end_pattern . '}'] = '\\1' . Horde::img($icon . '.png', $string, array('align' => 'middle', 'title' => $string), $iconpath) . (($this->_params['entities']) ? '\\2' : '');
+        /* Build the patterns. */
+        $patterns = array_keys($this->getIcons());
+        $beg_pattern = '(^|\s)(';
+        $end_pattern = ')(?=\s)';
+        if ($this->_params['entities']) {
+            $patterns = array_map('htmlspecialchars', $patterns);
+            $beg_pattern = '(^|\s|<br />|&nbsp;)(';
+            $end_pattern = ')(?=\s|<br />|&nbsp;)';
         }
+        $patterns = array_map('preg_quote', $patterns);
+
+        /* Check for a smiley either immediately at the start of a line or
+         * following a space. Use {} as the preg delimiters as this is not
+         * found in any smiley. */
+        $regexp['{' . $beg_pattern . implode('|', $patterns) . $end_pattern . '}e'] = 'Text_Filter_emoticons::getImage(\'$2\', \'$1\', \'' . ($this->_params['entities'] ? '$3' : '') . '\')';
 
         return array('regexp' => $regexp);
     }
 
     /**
-     * Returns a hash with emoticons and names.
+     * Returns the img tag for an emoticon.
      *
-     * @return array  Patterns hash.
+     * @see Text_Filter_emoticons::getPatterns()
+     * @since Horde 3.1.4
+     *
+     * @param string $icon  The emoticon.
+     * @param string $prefix  A html prefix.
+     * @param string $postfix  A html postfix.
+     *
+     * @return string  HTML code with the image tag and any additional prefix
+     *                 or postfix.
      */
-    function getIcons()
+    function getImage($icon, $prefix, $postfix)
+    {
+        static $iconpath;
+        if (empty($iconpath)) {
+            $iconpath = $GLOBALS['registry']->getImageDir('horde') . '/emoticons';;
+        }
+
+        return $prefix . Horde::img(Text_Filter_emoticons::getIcons($icon) . '.png', $icon, array('align' => 'middle', 'title' => $icon), $iconpath) . $postfix;
+    }
+
+    /**
+     * Returns a hash with all emoticons and names or the name of a single
+     * emoticon.
+     *
+     * @param string $icon  If set, return the name for that emoticon only.
+     *                      @since Horde 3.1.4
+     *
+     * @return array|string  Patterns hash or icon name.
+     */
+    function getIcons($icon = null)
     {
         /* List complex strings before simpler ones, otherwise for example :((
          * would be matched against :( before :(( is found. */
-        return array(
+        static $icons = array(
             ':/' => 'frustrated', ':-/' => 'frustrated',
             // ':*>' => 'blush',
             ':e' => 'disappointed',
@@ -119,6 +143,12 @@ class Text_Filter_emoticons extends Text_Filter {
             ':@' => 'shout',
             ':(' => 'frown',
         );
+
+        if ($icon) {
+            return isset($icons[$icon]) ? $icons[$icon] : null;
+        } else {
+            return $icons;
+        }
     }
 
 }
