@@ -2,9 +2,9 @@
 /**
  * The Horde_UI_VarRenderer_html:: class renders variables to HTML.
  *
- * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.28 2006/08/16 12:17:22 jan Exp $
+ * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.30 2007/01/02 13:54:46 jan Exp $
  *
- * Copyright 2003-2006 Jason M. Felice <jfelice@cronosys.com>
+ * Copyright 2003-2007 Jason M. Felice <jfelice@cronosys.com>
  *
  * See the enclosed file LICENSE for license information (LGPL).
  *
@@ -1052,6 +1052,7 @@ EOT;
         $address = $var->getValue($vars);
         $aus_state_regex = '(?:ACT|NSW|NT|QLD|SA|TAS|VIC|WA)';
 
+        $google_icon = 'map.png';
         if (preg_match('/((?:A[BL]|B[ABDHLNRST]?|C[ABFHMORTVW]|D[ADEGHLNTY]|E[CHNX]?|F[KY]|G[LUY]?|H[ADGPRSUX]|I[GMPV]|JE|K[ATWY]|L[ADELNSU]?|M[EKL]?|N[EGNPRW]?|O[LX]|P[AEHLOR]|R[GHM]|S[AEGKLMNOPRSTWY]?|T[ADFNQRSW]|UB|W[ACDFNRSV]?|YO|ZE)\d(?:\d|[A-Z])? \d[A-Z]{2})/', $address, $postcode)) {
             /* UK postcode detected. */
             /* Multimap.co.uk generated map */
@@ -1126,46 +1127,12 @@ EOT;
                 $mapurl2 .= '&csz=' . urlencode($addressParts[4]);
             }
 
-            /* Google generated map. */
-            $mapurl3 = 'http://maps.google.com/maps?q=' . urlencode($addressParts[0]) . '&hl=en';
-            $desc3 = _("Google Maps");
-            $icon3 = 'map.png';
-
         } elseif (preg_match('/(.*?)\r?\n([A-Z]{1,3})-(\d{5})\s+(.*)/i', $address, $addressParts)) {
             /* European address style. */
+            $google_icon = 'map_eu.png';
             include 'Horde/NLS/carsigns.php';
             $country = array_search(String::upper($addressParts[2]), $carsigns);
 
-            /* Map24 generated map. */
-            if (in_array($country, array('al', 'ad', 'am', 'az', 'be', 'ba',
-                                         'bg', 'de', 'dk', 'ee', 'fo', 'fi',
-                                         'fr', 'ge', 'gr', 'gb', 'ie', 'is',
-                                         'it', 'hr', 'lv', 'li', 'lt', 'lu',
-                                         'mt', 'mk', 'md', 'mc', 'nl', 'no',
-                                         'pl', 'pt', 'ro', 'ru', 'se', 'ch',
-                                         'cs', 'sk', 'si', 'es', 'cz', 'tr',
-                                         'ua', 'hu', 'by', 'cy', 'at'))) {
-                if (in_array($country, array('at', 'be', 'ch', 'de', 'dk',
-                                             'es', 'fi', 'fr', 'it', 'nl',
-                                             'no', 'se'))) {
-                    $mirror = $country;
-                } else {
-                    $mirror = 'uk';
-                }
-                $mapurl = 'http://www.' . $mirror . '.map24.com/source/address/v2.0.0/cnt_nav_maplet.php?cid=validateaddr&country=' . $country;
-                $desc = _("Map24 map");
-                $icon = 'map_eu.png';
-                if (!empty($addressParts[1])) {
-                    $mapurl .= '&street=' . urlencode($addressParts[1]);
-                }
-                if (!empty($addressParts[3])) {
-                    $mapurl .= '&zip=' . urlencode($addressParts[3]);
-                }
-                if (!empty($addressParts[4])) {
-                    $mapurl .= '&city=' . urlencode($addressParts[4]);
-                }
-            }
-
             /* Mapquest generated map. */
             $mapurl2 = 'http://www.mapquest.com/maps/map.adp?country=' . String::upper($country);
             $desc2 = _("MapQuest map");
@@ -1188,8 +1155,10 @@ EOT;
         if (!empty($mapurl2)) {
             $html .= '&nbsp;' . Horde::link(Horde::externalUrl($mapurl2), $desc2, null, '_blank') . Horde::img($icon2, $desc2, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
         }
-        if (!empty($mapurl3)) {
-            $html .= '&nbsp;' . Horde::link(Horde::externalUrl($mapurl3), $desc3, null, '_blank') . Horde::img($icon3, $desc3, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
+
+        /* Google generated map. */
+        if ($address) {
+            $html .= '&nbsp;' . Horde::link(Horde::externalUrl('http://maps.google.com/maps?q=' . urlencode($address) . '&hl=en'), _("Google Maps"), null, '_blank') . Horde::img($google_icon, _("Google Maps"), 'align="middle"', $registry->getImageDir('horde')) . '</a>';
         }
 
         return $html;
