@@ -13,10 +13,10 @@ define('HORDE_ERROR_DRIVER_CONFIG', 2);
 /**
  * The Util:: class provides generally useful methods of different kinds.
  *
- * $Horde: framework/Util/Util.php,v 1.384.6.17 2006/05/05 16:02:12 jan Exp $
+ * $Horde: framework/Util/Util.php,v 1.384.6.23 2007/01/11 18:55:50 chuck Exp $
  *
- * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 1999-2006 Jon Parise <jon@horde.org>
+ * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -110,10 +110,8 @@ class Util {
         } else {
             call_user_func_array($function, $args);
         }
-        $output = ob_get_contents();
-        ob_end_clean();
 
-        return $output;
+        return ob_get_clean();
     }
 
     /**
@@ -152,66 +150,64 @@ class Util {
      *                          an array of name/value pairs.
      * @param string $value     If specified, the value part ($parameter is
      *                          then assumed to just be the parameter name).
-     * @param boolean $encode   If true, and we don't have argument separators
-     *                          yet, the argument separator gets encoded.
+     * @param boolean $encode   Encode the argument separator?
      *
      * @return string  The modified URL.
      */
     function addParameter($url, $parameter, $value = null, $encode = true)
     {
-        static $translation_table;
-
-        if (!isset($translation_table)) {
-            $translation_table = array_flip(get_html_translation_table(HTML_ENTITIES));
-        }
         if (empty($parameter)) {
             return $url;
         }
 
-        /* Make sure to have an array. */
-        if (!is_array($parameter)) {
-            $add = array($parameter => $value);
-        } else {
-            $add = $parameter;
-        }
-
+        $add = array();
         $arg = $encode ? '&amp;' : '&';
-        if (($pos = strpos($url, '?')) === false) {
-            $glue = '?';
-        } else {
+
+        if (strpos($url, '?') !== false) {
+            list($url, $query) = explode('?', $url);
+
             /* Check if the argument separator has been already
              * htmlentities-ized in the URL. */
-            $query = substr($url, $pos + 1);
             if (preg_match('/=.*?&amp;.*?=/', $query)) {
+                $query = html_entity_decode($query);
                 $arg = '&amp;';
-                $query = strtr($query, $translation_table);
             } elseif (preg_match('/=.*?&.*?=/', $query)) {
                 $arg = '&';
             }
-            $pairs = explode($arg, $query);
-            $params = array();
+            $pairs = explode('&', $query);
             foreach ($pairs as $pair) {
-                $pair = explode('=', $pair, 2);
-                $params[$pair[0]] = count($pair) == 2 ? $pair[1] : '';
+                $pair = explode('=', urldecode($pair), 2);
+                $pair_val = (count($pair) == 2) ? $pair[1] : '';
+                if (substr($pair[0], -2) == '[]') {
+                    $name = substr($pair[0], 0, -2);
+                    if (!isset($add[$name])) {
+                        $add[$name] = array();
+                    }
+                    $add[$name][] = $pair_val;
+                } else {
+                    $add[$pair[0]] = $pair_val;
+                }
             }
-            $glue = $arg;
+        }
+        if (is_array($parameter)) {
+            $add = array_merge($add, $parameter);
+        } else {
+            $add[$parameter] = $value;
         }
 
         $url_params = array();
         foreach ($add as $parameter => $value) {
-            if (!isset($params[$parameter])) {
-                if (is_array($value)) {
-                    foreach ($value as $val) {
-                        $url_params[] = urlencode($parameter) . '[]=' . urlencode($val);
-                    }
-                } else {
-                    $url_params[] = urlencode($parameter) . '=' . urlencode($value);
+            if (is_array($value)) {
+                foreach ($value as $val) {
+                    $url_params[] = urlencode($parameter) . '[]=' . urlencode($val);
                 }
+            } else {
+                $url_params[] = urlencode($parameter) . '=' . urlencode($value);
             }
         }
 
         if (count($url_params)) {
-            return $url . $glue . implode($arg, $url_params);
+            return $url . '?' . implode($arg, $url_params);
         } else {
             return $url;
         }
@@ -228,11 +224,6 @@ class Util {
      */
     function removeParameter($url, $remove)
     {
-        static $translation_table;
-
-        if (!isset($translation_table)) {
-            $translation_table = array_flip(get_html_translation_table(HTML_ENTITIES));
-        }
         if (!is_array($remove)) {
             $remove = array($remove);
         }
@@ -249,7 +240,7 @@ class Util {
          * htmlentities-ized in the URL. */
         if (preg_match('/=.*?&amp;.*?=/', $query)) {
             $entities = true;
-            $query = strtr($query, $translation_table);
+            $query = html_entity_decode($query);
         }
 
         /* Get the list of parameters. */
@@ -657,16 +648,20 @@ class Util {
 
         foreach ($files as $file => $val) {
             /* Delete files */
-            if ($val && @file_exists($file)) {
-                /* Should we securely delete the file by overwriting the
-                   data with a random string? */
+            if ($val && file_exists($file)) {
+                /* Should we securely delete the file by overwriting the data
+                   with a random string? */
                 if (isset($secure[$file])) {
-                    $random_str = '';
-                    for ($i = 0; $i < filesize($file); $i++) {
-                        $random_str .= chr(mt_rand(0, 255));
-                    }
+                    $filesize = filesize($file);
+                    /* See http://www.cs.auckland.ac.nz/~pgut001/pubs/secure_del.html.
+                     * We save the random overwrites for efficiency reasons. */
+                    $patterns = array("\x55", "\xaa", "\x92\x49\x24", "\x49\x24\x92", "\x24\x92\x49", "\x00", "\x11", "\x22", "\x33", "\x44", "\x55", "\x66", "\x77", "\x88", "\x99", "\xaa", "\xbb", "\xcc", "\xdd", "\xee", "\xff", "\x92\x49\x24", "\x49\x24\x92", "\x24\x92\x49", "\x6d\xb6\xdb", "\xb6\xdb\x6d", "\xdb\x6d\xb6");
                     $fp = fopen($file, 'r+');
-                    fwrite($fp, $random_str);
+                    foreach ($patterns as $pattern) {
+                        $pattern = substr(str_repeat($pattern, floor($filesize / strlen($pattern)) + 1), 0, $filesize);
+                        fwrite($fp, $pattern);
+                        fseek($fp, 0);
+                    }
                     fclose($fp);
                 }
                 @unlink($file);
