@@ -2,9 +2,9 @@
 /**
  * Class for providing garbage collection for any VFS instance.
  *
- * $Horde: framework/VFS/VFS/GC.php,v 1.4.12.8 2006/01/01 21:28:42 jan Exp $
+ * $Horde: framework/VFS/VFS/GC.php,v 1.4.12.10 2007/01/02 13:54:48 jan Exp $
  *
- * Copyright 2003-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -26,15 +26,22 @@ class VFS_GC {
     function gc(&$vfs, $path, $secs = 345600)
     {
         /* A 1% chance we will run garbage collection during a call. */
-        if (rand(0, 99) == 0) {
-            /* Make sure cleaning is done recursively. */
-            $files = $vfs->listFolder($path, null, true, false, true);
-            if (!is_a($files, 'PEAR_Error') && is_array($files)) {
-                $modtime = time() - $secs;
-                foreach ($files as $val) {
-                    if ($val['date'] < $modtime) {
-                        $vfs->deleteFile($path, $val['name']);
-                    }
+        if (rand(0, 99) != 0) {
+            return;
+        }
+
+        /* Use a backend-specific method if one exists. */
+        if (is_callable(array($vfs, 'gc'))) {
+            return $vfs->gc($path, $secs);
+        }
+
+        /* Make sure cleaning is done recursively. */
+        $files = $vfs->listFolder($path, null, true, false, true);
+        if (!is_a($files, 'PEAR_Error') && is_array($files)) {
+            $modtime = time() - $secs;
+            foreach ($files as $val) {
+                if ($val['date'] < $modtime) {
+                    $vfs->deleteFile($path, $val['name']);
                 }
             }
         }
