@@ -5,14 +5,14 @@
  * This file defines Horde's external API interface. Other
  * applications can interact with Horde through this API.
  *
- * $Horde: horde/lib/api.php,v 1.43.2.5 2006/05/04 13:27:28 jan Exp $
+ * $Horde: horde/lib/api.php,v 1.43.2.6 2007/01/29 12:30:05 jan Exp $
  *
  * @package Horde
  */
 
 /* Complex types. */
 $_types = array(
-    '{urn:horde}stringArray' => array(array('item' => 'string')),
+    'stringArray' => array(array('item' => 'string')),
     'hashItem' => array('key' => 'string', 'value' => 'string'),
     'hash' => array(array('item' => '{urn:horde}hashItem')),
     'hashHashItem' => array('key' => 'string', 'value' => '{urn:horde}hash'),
