@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/services/portal/index.php,v 1.39.10.7 2006/03/08 18:00:56 chuck Exp $
+ * $Horde: horde/services/portal/index.php,v 1.39.10.9 2007/03/09 17:27:36 jan Exp $
  *
- * Copyright 2003-2006 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2003-2007 Mike Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -33,7 +33,7 @@ if ($prefs->getValue('summary_refresh_time')) {
 
 // Load layout from preferences.
 $layout_pref = $prefs->getValue('portal_layout');
-if (!$layout_pref) {
+if (!$layout_pref || $layout_pref == 'a:0:{}') {
     $layout_pref = Horde_Block_Collection::getFixedBlocks();
 }
 $view = new Horde_Block_Layout_View($layout_pref);
